@@ -2,7 +2,6 @@
 This module provides an interface for invoking CMake executable.
 """
 
-
 from __future__ import annotations
 
 import argparse
@@ -38,13 +37,11 @@ RE_FILE_INSTALL = re.compile(r"""[ \t]*file\(INSTALL DESTINATION "([^"]+)".*"([^
 
 
 @overload
-def pop_arg(arg: str, args: Sequence[str], default: None = None) -> tuple[list[str], str | None]:
-    ...
+def pop_arg(arg: str, args: Sequence[str], default: None = None) -> tuple[list[str], str | None]: ...
 
 
 @overload
-def pop_arg(arg: str, args: Sequence[str], default: str) -> tuple[list[str], str]:
-    ...
+def pop_arg(arg: str, args: Sequence[str], default: str) -> tuple[list[str], str]: ...
 
 
 def pop_arg(arg: str, args: Sequence[str], default: str | None = None) -> tuple[list[str], str | None]:
@@ -275,6 +272,7 @@ class CMaker:
             cmake_source_dir,
             "-G",
             generator.name,
+            *generator.args,
             "--no-warn-unused-cli",
             f"-DCMAKE_INSTALL_PREFIX:PATH={cmake_install_prefix}",
             f"-DPYTHON_VERSION_STRING:STRING={python_version_string}",
@@ -297,15 +295,13 @@ class CMaker:
             )
             if python_include_dir:
                 cmd.append(f"{prefix}_INCLUDE_DIR:PATH={python_include_dir}")
-            if python_library and (
-                sys.platform.startswith("win") or tuple(int(x) for x in self.cmake_version.split(".")[:2]) >= (3, 24)
-            ):
+            if python_library and sysconfig.get_platform().startswith("win"):
                 cmd.append(f"{prefix}_LIBRARY:PATH={python_library}")
             if sys.implementation.name == "pypy":
                 cmd.append(f"{prefix}_FIND_IMPLEMENTATIONS:STRING=PyPy")
 
             with contextlib.suppress(ImportError):
-                import numpy as np
+                import numpy as np  # pylint: disable=import-outside-toplevel
 
                 cmd.append(f"{prefix}_NumPy_INCLUDE_DIRS:PATH=" + np.get_include())
 
@@ -519,9 +515,11 @@ class CMaker:
                     libdir_masd = os.path.join(libdir, masd)
                     if os.path.exists(libdir_masd):
                         libdir = libdir_masd
-            libpath = os.path.join(libdir, ldlibrary)
-            if libpath and os.path.exists(libpath):
-                return libpath
+            libpath = Path(libdir) / ldlibrary
+            if sys.platform.startswith("win") and libpath.suffix == ".dll":
+                libpath = libpath.with_suffix(".lib")
+            if libpath.is_file():
+                return str(libpath)
 
         return CMaker._guess_python_library(python_version)
 
@@ -602,9 +600,12 @@ class CMaker:
                     python_library = candidate
                     break
 
-        # TODO(opadron): what happens if we don't find a libpython?
-
-        return python_library
+        # Temporary workaround for some libraries (opencv) processing the
+        # string output.  Will return None instead of empty string in future
+        # versions if the library does not exist.
+        if python_library is None:
+            return None
+        return python_library if python_library and os.path.exists(python_library) else ""
 
     @staticmethod
     def check_for_bad_installs() -> None:
@@ -641,17 +642,16 @@ class CMaker:
                         bad_installs.append(os.path.join(destination, os.path.basename(match.group(2))))
 
         if bad_installs:
-            raise SKBuildError(
-                "\n".join(
-                    (
-                        "  CMake-installed files must be within the project root.",
-                        "    Project Root:",
-                        "      " + install_dir,
-                        "    Violating Files:",
-                        "\n".join(("      " + _install) for _install in bad_installs),
-                    )
+            msg = "\n".join(
+                (
+                    "  CMake-installed files must be within the project root.",
+                    "    Project Root:",
+                    f"      {install_dir}",
+                    "    Violating Files:",
+                    "\n".join(f"      {_install}" for _install in bad_installs),
                 )
             )
+            raise SKBuildError(msg)
 
     def make(
         self,
@@ -749,8 +749,8 @@ class CMaker:
     def _parse_manifests(self) -> list[str]:
         paths = glob.glob(os.path.join(CMAKE_BUILD_DIR(), "install_manifest*.txt"))
         try:
-            return [self._parse_manifest(path) for path in paths][0]
-        except IndexError:
+            return next(self._parse_manifest(path) for path in paths)
+        except StopIteration:
             return []
 
     @staticmethod
